package space.kklochko.spring_rest_example.controllers;

import jakarta.persistence.EntityManager;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import space.kklochko.spring_rest_example.db.repositories.IndicatorRepository;
import space.kklochko.spring_rest_example.models.Indicator;

import java.util.List;
import java.util.UUID;

@RestController
@RequestMapping("/api/v1/indicators")
public class IndicatorController {
    @Autowired
    EntityManager manager;

    @Autowired
    IndicatorRepository indicatorRepository;

    @PostMapping
    @ResponseBody
    public ResponseEntity<Object> create(@RequestBody Indicator indicator) {
        Indicator isExist = indicatorRepository.read(indicator.getId());

        if(isExist != null)
            return ResponseEntity.status(500).body("Failed to create the indicator, because the id is already used!!!");

        boolean successful = indicatorRepository.create(indicator);

        if(!successful)
            return ResponseEntity.status(500).body("Failed to create the indicator");

	return ResponseEntity.status(201).body("The indicator created successfully");
    }

    @GetMapping("/{id}")
    @ResponseBody
    public ResponseEntity<?> get(@PathVariable UUID id) {
        Indicator indicator = indicatorRepository.read(id);

        if(indicator == null)
            return new ResponseEntity<>("Indicator not found", HttpStatus.NOT_FOUND);

        return new ResponseEntity<>(indicator, HttpStatus.OK);
    }

    @GetMapping
    @ResponseBody
    public List<Indicator> getAll() {
        return indicatorRepository.readAll();
    }

    @PutMapping
    @ResponseBody
    public ResponseEntity<Object> update(@RequestBody Indicator indicator) {
        Indicator isExist = indicatorRepository.read(indicator.getId());

        if(isExist == null)
            return ResponseEntity.status(500).body("Failed to update the indicator, because the indicator does not exist!!!");

        boolean successful = indicatorRepository.update(indicator);

        if(!successful)
            return ResponseEntity.status(500).body("Failed to update the indicator.");

        return ResponseEntity.status(200).body("The indicator updated successfully");
    }

    @DeleteMapping("/{id}")
    @ResponseBody
    public ResponseEntity<Object> delete(@PathVariable UUID id) {
        boolean successful = indicatorRepository.delete(id);

        if(!successful)
            return ResponseEntity.status(500).body("Failed to delete the indicator, because the indicator does not exist!!!");

        return ResponseEntity.status(201).body("The indicator deleted successfully");
    }
}
