package space.kklochko.spring_rest_example.db.repositories;

import jakarta.persistence.EntityGraph;
import jakarta.persistence.EntityManager;
import jakarta.persistence.NoResultException;
import jakarta.persistence.TypedQuery;
import org.springframework.stereotype.Component;
import space.kklochko.spring_rest_example.db.repositories.blocks.TransactionalInsert;
import space.kklochko.spring_rest_example.db.repositories.blocks.TransactionalRemove;
import space.kklochko.spring_rest_example.db.repositories.blocks.TransactionalUpdate;
import space.kklochko.spring_rest_example.models.Token;

import java.util.List;
import java.util.UUID;

@Component
public class TokenRepository extends AbstractRepository<Token> {
    public TokenRepository(EntityManager manager) {
        super(manager);
    }

    public boolean create(Token object) {
        TransactionalInsert insert = new TransactionalInsert();

        return insert.run(manager, object);
    }

    public Token read(UUID id) {
        return manager.find(Token.class, id);
    }

    public Token read(String token) {
        TypedQuery<Token> query = manager.createQuery("SELECT t FROM Token t WHERE t.token = :token", Token.class);

        try {
            return query
                    .setParameter("token", token)
                    .getSingleResult();
        }catch (NoResultException e) {
            return null;
        }
    }

    public List<Token> readAll() {
        TypedQuery<Token> query = manager.createQuery("SELECT t FROM Token t", Token.class);

        return query.getResultList();
    }

    public boolean update(Token object) {
        TransactionalUpdate update = new TransactionalUpdate();

        return update.run(manager, object);
    }

    public boolean delete(UUID id) {
        Token object = read(id);

        TransactionalRemove remove = new TransactionalRemove();

        return remove.run(manager, object);
    }
}

