package space.kklochko.spring_rest_example.interceptors;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpMethod;
import org.springframework.web.servlet.HandlerInterceptor;
import space.kklochko.spring_rest_example.security.access.AuthorizedValidator;

import java.io.IOException;
import java.util.Map;
import java.util.TreeMap;

public class AuthorizedInterceptor implements HandlerInterceptor {
    @Autowired
    AuthorizedValidator authorizedValidator;

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        if (request.getMethod().equals(HttpMethod.GET.name())) {
            return true;
        }

        String token = request.getHeader("Authorization");

        Boolean accessStatus;

        if (request.getMethod().equals(HttpMethod.DELETE.name())) {
            accessStatus = authorizedValidator.isAdmin(token);
        }else {
            accessStatus = authorizedValidator.isUser(token);
        }

        if(accessStatus == null) {
            sendJsonError(response, HttpServletResponse.SC_UNAUTHORIZED, authorizedValidator.noToken());
            return false;
        }

        if(!accessStatus) {
            sendJsonError(response, HttpServletResponse.SC_FORBIDDEN, authorizedValidator.accessDeniedNoPermission());
            return false;
        }

        return true;
    }

    private void sendJsonError(HttpServletResponse response, int status, String message) {
        response.setStatus(status);
        response.setContentType("application/json");

        Map<String, Object> errorResponse = new TreeMap<>();
        errorResponse.put("error", message);

        ObjectMapper objectMapper = new ObjectMapper();
        String json;

        try {
            json = objectMapper.writeValueAsString(errorResponse);
        } catch (JsonProcessingException e) {
            throw new RuntimeException(e);
        }

        try {
            response.getWriter().write(json);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }
}

